@@ -24,7 +24,7 @@
 #include <stdio.h>
 
 /* the next line is just so that I can use "c6.n" instead of "coxfit6.n", etc*/
-extern struct coxfit6 c6;
+struct coxfit6 c6;
 static void update(int j, int upper);
 static double dsum1, dsum2;
 static int nvar3;
